---
title: 가입신청 이후 PG사로부터 연락을 못받았습니다!
category: 자주 묻는 질문 (일반 문의) > 일반 문의 > 자주 묻는 질문
seo:
  description: 결제대행사 가입신청 이후 연락을 못받으셨을 때 확인해볼 수 있는 사항을 안내드립니다.
tags:
  - 공통
  - 계약절차
pgCompanies:
  - 공통
searchTags:
  - PG사계약
  - PG사 안내지연
  - 계약지연
datetime: 2024-04-18T07:50:48.484Z
---

<Callout content="결제대행사 가입 신청 이후, 계약담당자로부터 약 3영업일 내 계약안내를 받으실 수 있습니다.
만약 연락을 받지 못하셨다면 아래 내용을 자세히 참고해주시기 바랍니다." />

### **1. 가입신청 이후 PG사별 다음 프로세스 확인**

결제대행사에 따라 신청 이후 결제대행사에서 직접 안내가 되는 곳과 귀사(가맹점) 접수가 한번 더 필요한 곳도 있습니다.  신청하신 결제대행사는 어떤 절차에 해당되는지 먼저 확인해주시기 바랍니다.

- [결제대행사별 상세 계약절차 보러가기↗](https://help.portone.io/category/core-service/how-to-use?page=1)

### **2. 가입신청서 제출일자 확인 (보통 영업일 기준 3일 소요)**

포트원에서는 접수된 당일 접수된 신청서는 당일 내 접수 처리해드리고 있습니다. (포트원→ PG사)

결제대행사에서는 접수된 신청서를 기준으로 순차적으로 안내를 주시며 약 3영업일 소요됩니다.

### **3. 메일주소 확인하기**

가입신청 이후 안내되는 메일은 신청서에 작성하신 담당자님의 메일주소로 발송됩니다.

[포트원 관리자콘솔 ↗](https://admin.portone.io/payments) > 상점・계정 관리 > 사업자정보 하단 담당자 정보 에서 확인하실 수 있습니다.

### **4. 수신 메일함 , 스팸 메일함 확인하기**

PG사의 안내메일은 종종 스팸 메일함에 누락되기도 합니다.  계약이 지연되지 않도록 반드시 담당자님의 수신메일함, 스팸메일함 꼭 확인해주시기 바랍니다.

### **5. 사이트 구축이 완료되었는지 확인하기**

포트원에서는 당일 내 PG사로 접수신청을 전달하나 일부 가맹점의 경우 홈페이지 미구축 사유로 인하여 결제대행사 접수 전 ‘접수보류’ 처리가 되기도 합니다.

기재하신 홈페이지 내 심사를 위한 필수 정보가 누락되어있을 경우 결제대행사로 접수되지 않고 보류처리된 후 상세내용을 메일로 안내드리오니 사이트가 올바르게 구축되어있는지 미리 확인해주시기 바랍니다.

- [사이트 필수 구축요건 보러가기↗](https://help.portone.io/content/requirements)
